@@ -26,7 +26,8 @@
 
 #include <QDialog>
 
-namespace Ui {
+namespace Ui
+{
 class EditShare;
 }
 
